@@ -27,6 +27,7 @@ if PY_VERSION > (3, 0):
     xrange = range
     from itertools import zip_longest
     from functools import reduce
+    from collections.abc import Iterable
 
 else:
 
@@ -48,17 +49,4 @@ else:
     xrange = xrange
     from itertools import izip_longest as zip_longest
     reduce = reduce
-
-try:
-    from mock import call as mock_call
-except ImportError:  # pragma: no cover
-    class MockCall:
-        pass
-    mock_call = MockCall()
-
-try:
-    from unittest.mock import call as unittest_mock_call
-except ImportError:
-    class UnittestMockCall:
-        pass
-    unittest_mock_call = UnittestMockCall()
+    from collections import Iterable
